<?php
namespace Teknisa\CMP\Modules\Fornecimento\Modules\AutorizacaoFornecimento\Controllers;

use \Teknisa\GER\Utilities\Environment;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Message;

class SqlPesqProd extends \Teknisa\GER\Controllers\TeknisaCrud {
	
	protected $dataSourceManager;
	protected $environment;
	protected $parameterBag;
	protected $crudService;
	protected $entityManager;

	public function __construct($crudService, $parameterBag, $entityManager, Manager $dataSourceManager, Environment $environment) 
	{
		$this->crudService 				= $crudService;
		$this->parameterBag 			= $parameterBag;
		$this->entityManager 			= $entityManager;
		$this->dataSourceManager 	= $dataSourceManager;
		$this->environment 				= $environment;
	}

	public function find(DTO\Request\Filter $request, DTO\Response $response) 
	{

		try {
			$filterCriteria = $request->getFilterCriteria()->getConditions();

			$cdfilial = $filterCriteria[0]['value'];
			$idprodnvcompl = $filterCriteria[1]['value'];
			$cdfilcentcmp = $filterCriteria[2]['value'];
			$cdforneced = $filterCriteria[3]['value'];
			$dtautoforn = explode(' ',$filterCriteria[4]['value'])[0];
			$cdcomprador = $filterCriteria[5]['value'];
			$nrorg = $filterCriteria[6]['value'];

			$query = $this->entityManager->getConnection()->prepare('SELECT * FROM TABLE(SQL_PESQ_PROD(:CDFILIAL, :IDPRODNVCOMPL, :CDFILCENTCMP, :CDFORNECED, :DTAUTOFORN, :CDOPERADOR, :NRORG)) ORDER BY CDPRODUTO');
			$query->execute(
				array(
					'CDFILIAL' => $cdfilial,
					'IDPRODNVCOMPL' => $idprodnvcompl,
					'CDFILCENTCMP' => $cdfilcentcmp,
					'CDFORNECED' => $cdforneced,
					'DTAUTOFORN' => $dtautoforn,
					'CDOPERADOR' => $cdcomprador,
					'NRORG' => $nrorg
				)
			);

			$dataSet = $query->fetchAll();

			$erros = array(
				'ERRO_SQL_PESQUISA_PRODUTO'  => "Erro ao executar a função SQL_PESQUISA_PRODUTO",
				'ERRO_SQL_PESQ_PROD_FORN' 	 => "Erro ao executar a função SQL_PESQ_PROD_FORN",
				'NAO_HA_PRODUTOS_SEM_COMP' 	 => "Não há produto sem composição cadastrado",
				'NAO_HA_PRODUTOS_SEGMENTO' 	 => "Não há produto cadastrado para o segmento de mercado da unidade",
				'NAO_HA_PRODUTO_MODULO' 	 => "Não há produto cadastrado para o módulo da unidade",
				'NAO_HA_PRODUTOS_SEG_MODULO' => "Não há produto cadastrado para o segmento de mercado e módulo da unidade",
				'NAO_HA_PRODUTO_CADASTRADO'  => "Não há produto cadastrado",
				'NAO_HA_PARAM_FILIAL' 		 => "Não há parametrização cadastrada para a unidade",
				'FILIAL_NAO_CADASTRADA' 	 => "Unidade não cadastrada",
				'NAO_HA_PROD_FORN' 		 	 => "Não há produtos por fornecedor",
				'NAO_HA_PROD_QUALIF_FORN' 	 => "Não há produtos com qualificação por fornecedor",
				'NVL_COMPLET_SEM_PRODUTO_POR_FILIAL' 	=> "Não há produto de nível completo cadastrado para a unidade",
				'NVL_IMCOMP_SEM_PRODUTO_POR_FILIAL' 	=> "Não há produto de nível imcompleto cadastrado para a unidade",
				'NVL_COMPLET_SEM_PRODUTO_CMP_FILIAL' 	=> "Não há produto de nível completo comprado pela unidade",
				'NVL_IMCOMP_SEM_PRODUTO_CMP_FILIAL' 	=> "Não há produto de nível imcompleto comprado pela unidade",
				'NAO_HA_RELAC_PROD_OL' 					=> "Não há relacionamento de produtos OL",
				'NAO_HA_RELAC_PROD_OL_POR_COMPRADOR' 	=> "Não há relacionamento de produtos OL por comprador",
				'NAO_HA_PROD_COMPRADOR' 				=> "Não há produto por comprador"
			);

			if (sizeof($dataSet) === 1 && $dataSet[0]["DSERRO"] !== null) {

				$mensagem = $erros[$dataSet[0]["DSERRO"]];
				throw new \Exception($mensagem);

			} else  {

				$response->addDataSet( new DataSet('SQL_PESQ_PROD', $dataSet));

			}

		} catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }

	}

}