<?php
namespace Teknisa\CMP\Modules\Fornecimento\Modules\AutorizacaoFornecimento\Services;

use Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Doctrine\ORM\EntityManager;
use Teknisa\CMP\Util\CmpUtilities;

class Cmp04200LiberacaoDeAfInconsistenteForaDoLimiteService
{
 
    protected $crudService;
    protected $entityManager;
    protected $connection;
    protected $smtpUtil;
    protected $environment;
    protected $cmpUtilities;
    
    public function __construct($crudService,$entityManager, $smtpUtil, $environment, CmpUtilities $cmpUtilities)
    {
        $this->crudService  = $crudService;
        $this->connection  = $entityManager->getConnection();
        $this->smtpUtil    = $smtpUtil;
        $this->environment = $environment;
        $this->cmpUtilities = $cmpUtilities;
        
    }

    public function enviarEmailParaOperadoresResponsaveisPelaAf($row)
    {
        $operadorLogado = $this->obtemNmOperador();
        $rowOperador = $row["OPERADORES_RESPONSAVEIS"] ;
        unset($row["OPERADORES_RESPONSAVEIS"]);
        
        $this->cmpUtilities->useCustomSmtp();
        
        foreach ($rowOperador as $operator) {
            try {
                $email = array(
                    "NOME_OPERADOR" => $operator["NMOPERADOR"],
                    "EMAIL" => $operator["DSEMAILOPER"],
                    "NMFILIAL" => $operator["NMFILIAL"]
                   
                );
                
                $lista = "";
                foreach ($row as $listaAf) {
                   $lista = $lista."<ul> <li> <div> Nº da AF: <i>" . " " . $listaAf["NRAUTOFORN"] . " " . "Unidade Destino:" . " " . $listaAf['CDFILDEST'] . " - " . $email["NMFILIAL"] . " " . "</i></div> </li> </ul>";
                }
                
                $assunto = 'Liberação de AF Inconsistente/Fora do Limite';
                $message = "<table>
                            <tr>
                                <td class='title'> 
                                    <div>
                                        <br/>" . $assunto . "
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class='description'>
                                    <div style='margin: 10px;'> <b>Olá,&nbsp;comprador</b>
                                        <p>As seguintes AF's inconsistentes/fora do limite foram liberadas para compra:</p> ". $lista ." </div>
                                </td>
                            </tr>
                            <tr class='footer'>
                                <td>
                                    <center>
                                        <br> <p> Email automático enviado pelo Compras. </p> 
                                    </center>
                                </td>
                            </tr>
                        </table>";
                
                $messageSendMail = $this->cmpUtilities->messageSendMail($this->environment->getCdFilial(), $assunto, $message, 'PORTAL E-COMMERCE');

                $this->cmpUtilities->enviaEmail('', $assunto, $email["EMAIL"], $messageSendMail, $email["EMAIL"]);
            } catch (\Exception $e) {
                throw $e;
            }
        }
    }
    
    public function obtemNmOperador()
    {
        $query      = "SELECT NMOPERADOR FROM OPERADOR WHERE CDOPERADOR = :P_CDOPERADOR";
        $nmoperador = array(
            "P_CDOPERADOR" => $this->environment->getCdOperador()
        );
        try {
            $std = $this->connection->prepare($query);
            $std->execute($nmoperador);
            return $std->fetchAll();
        }
        catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function obtemOperadoresResponsaveisPelaAf($selectParams)
    {
        
        $select = "SELECT DISTINCT OPERADOR.CDOPERADOR,
                      FILIAL.NMFILIAL,
                      OPERADOR.NMOPERADOR,
                      OPERADOR.DSEMAILOPER,
                      OPERADOR.NRORG
                    FROM COMPROPER,
                      OPERADOR,
                      FILIAL
                    WHERE ((COMPROPER.CDOPERADOR = OPERADOR.CDOPERADOR
                    AND COMPROPER.CDCOMPRADOR    = :P_CDOPERADOR
                    AND COMPROPER.IDAFCMPOPER    = 'S')
                    OR (OPERADOR.CDOPERADOR      = :P_CDOPERADOR))
                    AND FILIAL.CDFILIAL          = :P_CDFILDEST";
        
        try {
            $std = $this->connection->prepare($select);
            $std->execute($selectParams);
            return $std->fetchAll();
        }
        catch (\Exception $e) {
            throw $e;
        }
        
    }
    
    public function senhaGerente($row) {   
          
        $query = $this->connection->prepare(
            "SELECT CDSENHAOPERWEB FROM OPERADOR WHERE CDOPERADOR = :CDGERENTE");
        $query->execute(array(
          
            "CDGERENTE" => $row["CDGERENTE"]
        ));
        $existe = $query->fetchAll();

        if(sizeof($existe) > 0)
            return $existe[0]["CDSENHAOPERWEB"];
        else
            return false;
    }
    
    public function getIdUtilizaWorkflow($row) {   
        $query = "SELECT IDUTLWORKFLOW FROM PARASUPRI WHERE CDFILIAL = (SELECT NVL(CDFILCENTCMP, CDFILIAL) CDFILCENTCMP FROM FILIAL WHERE CDFILIAL = :P_CDFILIAL)";
        
        $params = array(
            "P_CDFILIAL" => $row['CDFILDEST']
        );
        
        $std = $this->connection->prepare($query);
        $std->execute($params);
        
        return $std->fetch();
    }
    
    public function deletarAprovacoesAlcadasExistentes($row) {   
        $query = "DELETE FROM APROVALCADA WHERE NRDEMANDA = :P_NRAUTOFORN";
        
        $params = array(
            "P_NRAUTOFORN" => $row['NRAUTOFORN']
        );
        
        $std = $this->connection->prepare($query);
        $std->execute($params);
    }
}
